@@ -101,6 +101,9 @@ INVALIDPARAMETER_CONTENT = 'InvalidParameter.Content'
 # 数据库唯一键冲突。
 INVALIDPARAMETER_DBDUPLICATION = 'InvalidParameter.DbDuplication'
 
+# 导出任务已经存在。
+INVALIDPARAMETER_EXPORTCONFLICT = 'InvalidParameter.ExportConflict'
+
 # 低频不支持配置kv和tag索引。
 INVALIDPARAMETER_INVALIDINDEXRULEFORSEARCHLOW = 'InvalidParameter.InValidIndexRuleForSearchLow'
 
@@ -147,11 +150,14 @@ LIMITEXCEEDED_MACHINEGROUP = 'LimitExceeded.MachineGroup'
 LIMITEXCEEDED_MACHINEGROUPIP = 'LimitExceeded.MachineGroupIp'
 
 # 机器组Label超过限制。
-LIMITEXCEEDED_MACHINEGROUPLABELS = 'LimitExceeded.MachineGroupLabels'
+LIMITEXCEEDED_MACHINEGROUPIPLABELS = 'LimitExceeded.MachineGroupIpLabels'
 
 # 分区超过限制。
 LIMITEXCEEDED_PARTITION = 'LimitExceeded.Partition'
 
+# 检索内存超限。
+LIMITEXCEEDED_SEARCHRESOURCES = 'LimitExceeded.SearchResources'
+
 # 检索接口返回的日志量太大， 超过20MB限制。
 LIMITEXCEEDED_SEARCHRESULTTOOLARGE = 'LimitExceeded.SearchResultTooLarge'
 
